Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: lib/requestBlocker.js

Issue 29680696: [$csp4 adblockpluschrome] Issue 5241 - Add support for Content Security Policy filters (Closed)
Patch Set: Get devtools logging working Created March 7, 2018, 3 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: lib/requestBlocker.js
diff --git a/lib/requestBlocker.js b/lib/requestBlocker.js
index 56f6313cea25fe63ebfef2c5b0498a70f989117b..a26cab4deb9570d02aa4d8386e5764096200e488 100644
--- a/lib/requestBlocker.js
+++ b/lib/requestBlocker.js
@@ -68,10 +68,12 @@ exports.filterTypes = new Set(function*()
yield "WEBSOCKET";
yield "WEBRTC";
// POPUP and ELEMHIDE filters aren't blocked on the request level but by other
// means. They don't have a corresponding value in webRequest.ResourceType.
yield "POPUP";
yield "ELEMHIDE";
+ yield "CSP";
}());
function onBeforeRequestAsync(page, url, type, docDomain,
@@ -68,10 +68,12 @@ exports.filterTypes = new Set(function*()
yield "WEBSOCKET";
yield "WEBRTC";
- // POPUP and ELEMHIDE filters aren't blocked on the request level but by other
- // means. They don't have a corresponding value in webRequest.ResourceType.
+ // POPUP, CSP and ELEMHIDE filters aren't blocked on the request level but by
+ // other means. They don't have a corresponding value in
+ // webRequest.ResourceType.
yield "POPUP";
yield "ELEMHIDE";

Powered by Google App Engine
This is Rietveld